beeSurvFit objectPredict the Lethal Concentration at which \(x\%\) of organisms die for any
specified time-point for a beeSurvFit object
# S3 method for beeSurvFit
LCx(
object,
X = 50,
testType = "Chronic_Oral",
timeLCx = NULL,
concRange = NULL,
nPoints = 100,
ncores = NULL,
...
)A object of class LCx containing the results of the lethal concentration predictions
An object of class beeSurvFit
Percentage of individuals dying (e.g., \(50\) for the \(LC_{50}\))
Test type for which the \(LC_{X}\) is calculated amongst "Acute_Oral", "Acute_Contact", and "Chronic_Oral". Note that for "Acute_Oral" and "Acute_Contact", the concentration will be reconstructed as in the dataGUTS function (not recommended as this might not make sense for \(LC_{X}\) estimations. Default is "Chronic_Oral"
A scalar giving the time at which \(LC_{x}\) is predicted.
If NULL, the latest time point of the experiment used in the calibration is used
A vector of length 2 with minimal and maximal value of the
range of concentration. If NULL, the range is define between 0 and the
highest tested concentration of the calibration experiment.
Number of time point in concRange between 0 and the
maximal concentration. 100 by default.
Number of cores for parallelization
Further arguments to be passed to generic methods
# \donttest{
data(fitBetacyfluthrin_Chronic)
out <- LCx(fitBetacyfluthrin_Chronic,ncores=2)
# }
Run the code above in your browser using DataLab