Learn R Programming

BeeGUTS (version 1.5.0)

TRT.beeSurvFit: Calculate the presence of Time Reinforced Toxicity for the compound from the calibrated model beeSurvFit object.

Description

Calculate the presence of Time Reinforced Toxicity for the compound from the calibrated model beeSurvFit object.

Usage

# S3 method for beeSurvFit
TRT(object, concRange = NULL, ncores = NULL)

Value

A object of class ggplot containing the graph of the comparison between Haber's law and the predicted lethal doses at 10 and 27 days and a data.frame with the plotted values.

Arguments

object

An object of class beeSurvFit

concRange

Argument of LCx, range of concentrations to find LDD50

ncores

Argument of LCx, number of cores for parallelization

Examples

Run this code
# \donttest{
data(fitBetacyfluthrin_Chronic)
TRT(fitBetacyfluthrin_Chronic,ncores=2)
# }

Run the code above in your browser using DataLab