Survival datasets for Honey bees exposed to constant concentration of Betacyfluthrin for 10 days.
data(betacyfluthrinChronic)A list of class beeSurvData constructed by dataGUTS containing:
nDatasetsAn integer representing the number of datasets used.
survDataA data frame containing the survival information over time for five treatments and a control in a wide format.
survData_longA data frame containing the survival information over time for five treatments and a control in a long format.
concDataA data frame containing the concentration information over time for five treatments and a control in a wide format.
concData_longA data frame containing the concentration information over time for five treatments and a control in a long format.
unitDataA character string containing the units of the concentration data.
typeDataA character string containing the type of data (here Chronic_Oral).
beeSpeciesA character string containing the species of bee of interest (here Honey_Bee).
concModelA data frame containing the concentration information recalculated for the species of bee and test type of interest in a wide format.
concModel_longA data frame containing the concentration information recalculated for the species of bee and test type of interest in a long format.
messagesA data frame containing the warning messages returned by the function.
Bayer data.