Learn R Programming

BeeGUTS (version 1.5.0)

valBetacyfluthrinChronic: Pre-calculated validation results for Honey bees exposed to constant concentration of Betacyfluthrin for 10 days. This is a toy example that uses the calibrated model of the object fitBetacyfluthrin_Chronic and the dataset betacyfluthrinChronic

Description

Pre-calculated validation results for Honey bees exposed to constant concentration of Betacyfluthrin for 10 days. This is a toy example that uses the calibrated model of the object fitBetacyfluthrin_Chronic and the dataset betacyfluthrinChronic

Usage

data(valBetacyfluthrinChronic)

Arguments

Format

A list of class beeSurvFit constructed by fitBeeGUTS containing:

parsPost

A data.frame with the summary of the posterior distribution of the model parameters.

modelType

A character string containing the type of GUTS model used (here 'SD').

unitData

A character string containing the units of the concentration data.

beeSpecies

A character string containing the species of bee of the model (here Honey_Bee).

beeSpeciesVal

A character string containing the species of bee of the validation dataset (here Honey_Bee).

typeData

A character string containing the type of data (here Chronic_Oral).

setupMCMC

A list containing the setup used for the MCMC.

sim

A data.frame with the results of the model prediction.

EFSA

A list containing the results of goodness of fit checks as defined by EFSA.

data

A data.frame with the user data used for the validation.

dataModel

A data.frame with the data that were used for the model calibration.

hbfit

NULL

References

Bayer data.