A object of class ggplot containing the graph of the comparison
between Haber's law and the predicted lethal doses at 10 and 27 days and a
data.frame with the plotted values.
Arguments
object
An object of class beeSurvFit
concRange
Argument of LCx, range of concentrations to find LDD50
ncores
Argument of LCx, number of cores for parallelization