Pre-calculated validation results for Honey bees exposed to constant concentration of Betacyfluthrin for 10 days. This is a toy example that uses the calibrated model of the object fitBetacyfluthrin_Chronic and the dataset betacyfluthrinChronic
data(valBetacyfluthrinChronic)A list of class beeSurvFit constructed by fitBeeGUTS containing:
parsPostA data.frame with the summary of the posterior distribution of the model parameters.
modelTypeA character string containing the type of GUTS model used (here 'SD').
unitDataA character string containing the units of the concentration data.
beeSpeciesA character string containing the species of bee of the model (here Honey_Bee).
beeSpeciesValA character string containing the species of bee of the validation dataset (here Honey_Bee).
typeDataA character string containing the type of data (here Chronic_Oral).
setupMCMCA list containing the setup used for the MCMC.
simA data.frame with the results of the model prediction.
EFSAA list containing the results of goodness of fit checks as defined by EFSA.
dataA data.frame with the user data used for the validation.
dataModelA data.frame with the data that were used for the model calibration.
hbfitNULL
Bayer data.